package schl

import (
	"context"
	"github.com/gogf/gf/encoding/gjson"
	"github.com/gogf/gf/util/gconv"
)

type OrderListReq struct {
	UnionNos         []int `json:"unionNos,omitempty"`
	PlatformOrderNos []int `json:"platformOrderNos,omitempty"`
}

type OrderListRes struct {
	CommonRes
	Result []struct {
		UnionNo            string  `json:"unionNo"`
		PlatformOrderNo    string  `json:"platformOrderNo"`
		TotalNum           int     `json:"totalNum"`
		TotalAmount        int     `json:"totalAmount"`
		TotalFreightAmount float64 `json:"totalFreightAmount"`
		PayAmount          float64 `json:"payAmount"`
		PayNo              string  `json:"payNo"`
		CustName           string  `json:"custName"`
		CustMobile         string  `json:"custMobile"`
		Province           string  `json:"province"`
		City               string  `json:"city"`
		District           string  `json:"district"`
		AddressDetail      string  `json:"addressDetail"`
		Remark             string  `json:"remark"`
		CreateTime         string  `json:"createTime"`
		PayTime            string  `json:"payTime"`
		OrderList          []struct {
			SuborderId       int     `json:"suborderId"`
			TotalGoodsAmount int     `json:"totalGoodsAmount"`
			FreightAmount    float64 `json:"freightAmount"`
			TotalAmount      float64 `json:"totalAmount"`
			State            int     `json:"state"`
			OrderDetailList  []struct {
				OrderDetailId int    `json:"orderDetailId"`
				SpecCode      string `json:"specCode"`
				SpecName      string `json:"specName"`
				SpecInfo      string `json:"specInfo"`
				Num           int    `json:"num"`
				UnitPrice     int    `json:"unitPrice"`
				TotalAmount   int    `json:"totalAmount"`
			} `json:"orderDetailList"`
			OrderDeliveredList []struct {
				ExpCode     string `json:"expCode"`
				ExpName     string `json:"expName"`
				ExpNo       string `json:"expNo"`
				PackageList []struct {
					OrderDetailId int    `json:"orderDetailId"`
					DeliveredNum  int    `json:"deliveredNum"`
					DeliveredTime string `json:"deliveredTime"`
				} `json:"packageList"`
			} `json:"orderDeliveredList"`
		} `json:"orderList"`
	} `json:"result"`
	TraceId string `json:"traceId"`
}

func (s *orderLogic) List(ctx context.Context, req OrderListReq) (res *OrderListRes, err error) {

	result, err := server.Post(ctx, "/open/xdxt/api/v2/order/listOrderInfo", gconv.Map(req))

	err = gjson.New(result).Scan(&res)
	if err != nil {
		return
	}
	return
}
